extension DateTimeExtensions on DateTime {

  Duration getTimeAsDuration() => Duration(hours: hour, minutes: minute, seconds: second, milliseconds: millisecond, microseconds: microsecond);
  bool isBeforeOrEqual(DateTime other, {bool compareSeconds = true, bool compareMillis = false, bool compareMicros = false}) {
    DateTime date1 = this;
    DateTime date2 = other;

    if (!compareSeconds) {
      date1 = date1.subtract(Duration(seconds: date1.second, milliseconds: date1.millisecond, microseconds: date1.microsecond));
      date2 = date2.subtract(Duration(seconds: date2.second, milliseconds: date2.millisecond, microseconds: date2.microsecond));
    }

    if (!compareMillis) {
      date1 = date1.subtract(Duration(milliseconds: date1.millisecond, microseconds: date1.microsecond));
      date2 = date2.subtract(Duration(milliseconds: date2.millisecond, microseconds: date2.microsecond));
    }

    if (!compareMicros) {
      date1 = date1.subtract(Duration(microseconds: date1.microsecond));
      date2 = date2.subtract(Duration(microseconds: date2.microsecond));
    }

    return date1.isBefore(date2) || date1.isAtSameMomentAs(date2);
  }

  DateTime get truncateTime => DateTime(year, month, day);

  bool get isToday {
    final nowDate = DateTime.now();
    return year == nowDate.year && month == nowDate.month && day == nowDate.day;
  }
}