import 'package:flutter/material.dart';

extension TimeOfDayExtensions on TimeOfDay {
  String toAmPmString() => "${hour.toString()}:${minute.toString().padLeft(2, '0')} ${hour > 11 ? "PM" : "AM"}";

  String toHrsMinString() => "${hour > 0 ? "$hour hrs " : ""}$minute mins";

  bool isBefore(TimeOfDay? other) => compareTo(other) < 0;
  bool isAfter(TimeOfDay? other) => compareTo(other) > 0;

  int compareTo(TimeOfDay? other) {
    if (other == null) {
      return 1;
    }

    if (hour < other.hour) return -1;
    if (hour > other.hour) return 1;
    if (minute < other.minute) return -1;
    if (minute > other.minute) return 1;
    return 0;
  }
}

extension NullableTimeOfDayExtensions on TimeOfDay? {
  String toAmPmString() => this != null ? "${this!.hour.toString()}:${this!.minute.toString().padLeft(2, '0')} ${this!.hour > 11 ? "PM" : "AM"}" : "";

  String toHrsMinString() => this != null ? "${this!.hour > 0 ? "${this!.hour} hrs " : ""}${this!.minute} mins" : "";

  bool isBefore(TimeOfDay? other) => compareTo(other) < 0;
  bool isAfter(TimeOfDay? other) => compareTo(other) > 0;

  int compareTo(TimeOfDay? other) {
    if (this == null) {
      return other == null ? 0 : -1;
    }

    if (other == null) {
      return 1;
    }

    if (this!.hour < other.hour) return -1;
    if (this!.hour > other.hour) return 1;
    if (this!.minute < other.minute) return -1;
    if (this!.minute > other.minute) return 1;
    return 0;
  }
}