import 'package:flutter/material.dart';

class SpacedColumn extends Column {
  final double widgetSpacing;

  SpacedColumn({
    super.key,
    required List<Widget> children,
    double spacing = 0.0,
    super.mainAxisAlignment,
    super.crossAxisAlignment,
    super.mainAxisSize,
    super.textDirection,
    super.verticalDirection,
    super.textBaseline,
    double flexSpacing = 0.0
  }) : widgetSpacing = spacing, super(
    children: _addSpacing(children, spacing),
    spacing: flexSpacing
  );

  static List<Widget> _addSpacing(List<Widget> children, double spacing) {
    if (children.isEmpty) return children;

    final List<Widget> spacedChildren = [];
    for (int i = 0; i < children.length - 1; i++) {
      spacedChildren.add(children[i]);
      spacedChildren.add(SizedBox(height: spacing));
    }
    spacedChildren.add(children.last);

    return spacedChildren;
  }
}

class SpacedRow extends Row {
  final double widgetSpacing;

  SpacedRow({
    super.key,
    required List<Widget> children,
    double spacing = 0.0,
    super.mainAxisAlignment,
    super.crossAxisAlignment,
    super.mainAxisSize,
    super.textDirection,
    super.verticalDirection,
    super.textBaseline,
    double flexSpacing = 0.0
  }) : widgetSpacing = spacing, super(
    children: _addSpacing(children, spacing),
    spacing: flexSpacing
  );

  static List<Widget> _addSpacing(List<Widget> children, double spacing) {
    if (children.isEmpty) return children;

    final List<Widget> spacedChildren = [];
    for (int i = 0; i < children.length - 1; i++) {
      spacedChildren.add(children[i]);
      spacedChildren.add(SizedBox(width: spacing));
    }
    spacedChildren.add(children.last);
    return spacedChildren;
  }
}